@@ -22,10 +22,10 @@
  * other programs which may modify your maildrops.
  * Currently you can only use one type.
  */
-#define DOT_LOCKING   1
-/* #define FCNTL_LOCKING 1 */
-/* #define LOCKF_LOCKING 1 */
-/* #define FLOCK_LOCKING 1 */
+#undef DOT_LOCKING
+#undef FCNTL_LOCKING
+#undef LOCKF_LOCKING
+#undef FLOCK_LOCKING
 
 /*
  * If you have defined DOT_LOCKING, then the default is to
@@ -114,12 +114,6 @@
 #define DEFAULT_FOLDER_MODE "700"
 #define DEFAULT_MESSAGE_MODE "600"
 
-/*
- * The prefix which is prepended to the name of messages when they
- * are "removed" by rmm.  This should typically be `,' or `#'
- */
-#define BACKUP_PREFIX ","
-
 /*
  * Name of link to file to which you are replying.
  */
@@ -158,21 +152,17 @@
 /***** END USER CONFIGURATION SECTION *****/
 @TOP@
 
+/*
+ * The prefix which is prepended to the name of messages when they
+ * are "removed" by rmm.  This should typically be `,' or `#'
+ */
+#define BACKUP_PREFIX ","
 
 /*
  * Define this if you want SMTP (simple mail transport protocol)
- * support.  When sending mail, instead of passing the message to
- * the mail transport agent (typically sendmail), nmh will open a
- * socket connection to the mail port on the machine specified in
- * the `mts.conf' file (default is localhost), and speak SMTP directly.
+ * support.  This is currently always enabled.
  */
-#undef SMTPMTS
-
-/*
- * Use sendmail as transport agent.  Post messages by piping
- * them directly to sendmail.
- */
-#undef SENDMTS
+#define SMTPMTS 1
 
 /*
  * Define this to compile client-side support for pop into
@@ -182,6 +172,14 @@
  */
 #undef POP
 
+/*
+ * Define this to compile client-side support for apop into
+ * inc and msgchk. Do not change this value manually. You
+ * must run configure with the '--enable-apop' option to
+ * correctly build the apop client support.
+ */
+#undef APOP
+
 /*
  * Define this to compile client-side support for kpop
  * (kerberized pop) into inc and msgchk.  Do not change this
@@ -195,6 +193,12 @@
  */
 #undef KPOP_PRINCIPAL
 
+/*
+ * Define this to use the Cyrus SASL library for authentication of
+ * POP and SMTP
+ */
+#undef CYRUS_SASL
+
 /*
  * Define this to compile support for using Hesiod to locate
  * pop servers into inc and msgchk.  Do not change this value
@@ -247,10 +251,6 @@
  */
 #undef MAILGROUP
 
-/* Define ruserpass as _ruserpass if your libraries have a bug *
- * such that it can't find ruserpass, but can find _ruserpass. */
-#undef ruserpass
-
 /* Define if your system defines TIOCGWINSZ in sys/ioctl.h.  */
 #undef GWINSZ_IN_SYS_IOCTL
 
@@ -260,6 +260,9 @@
 /* Define to 1 if struct tm has gmtoff */
 #undef HAVE_TM_GMTOFF
 
+/* Define to 1 if struct utmp has ut_type */
+#undef HAVE_UTMP_UT_TYPE
+
 /* Define if your system has sigsetjmp */
 #undef HAVE_SIGSETJMP
 
