@@ -1,8 +1,8 @@
-#! /bin/sh
+#!/bin/sh
 #
 # mhn.defaults.sh -- create extra profile file for MIME handling
 #
-# $Id: mhn.defaults.sh,v 1.4 2000/02/10 18:50:23 danh Exp $
+# $Id: mhn.defaults.sh,v 1.7 2000/04/12 00:25:23 danh Exp $
 #
 # USAGE: mhn.defaults.sh [ search-path [ search-prog ]]
 
@@ -126,13 +126,15 @@ if [ ! -z "$PGM" ]; then
 	echo "mhshow-show-application/x-ivs: %p$PGM -o '%F'" >> $TMP
 fi
 
+echo "mhshow-suffix-text/html: .html" >> $TMP
+
 # I'd like to check if netscape is available and use it preferentially to lynx,
 # but only once I've added a new %-escape that makes more permanent temp files,
 # so netscape -remote can be used (without -remote you get a complaint dialog
 # that another netscape is already running and certain things can't be done).
 PGM="`$SEARCHPROG $SEARCHPATH lynx`"
 if [ ! -z "$PGM" ]; then
-	echo "mhshow-show-text/html: %p$PGM -force_html '%F'" >> $TMP
+	echo "mhshow-show-text/html: %p$PGM '%F'" >> $TMP
 fi
 
 PGM="`$SEARCHPROG $SEARCHPATH richtext`"
@@ -145,9 +147,16 @@ else
     fi
 fi
 
+# staroffice to read .doc files
+PGM="`$SEARCHPROG $SEARCHPATH soffice`"
+if [ ! -z "$PGM" ]; then
+	echo "mhshow-show-application/msword: %psoffice '%F'" >> $TMP
+	echo "mhshow-suffix-application/msword: .doc" >> $TMP
+fi
+
 PGM="`$SEARCHPROG $SEARCHPATH xterm`"
 if [ ! -z "$PGM" ]; then
-	echo "mhshow-charset-iso-8859-1: xterm -fn '-*-*-medium-r-normal-*-*-120-*-*-c-*-iso8859-*' -e '%s'" >> $TMP
+	echo "mhshow-charset-iso-8859-1: xterm -fn '-*-*-medium-r-normal-*-*-120-*-*-c-*-iso8859-*' -e %s" >> $TMP
 fi
 
 # output a sorted version of the file
@@ -164,6 +173,7 @@ else
     PGM="`$SEARCHPROG $SEARCHPATH gs`"
     if [ ! -z "$PGM" ]; then
 	echo "mhshow-show-application/PostScript: %p$PGM -- '%F'" >> $TMP
+	echo "mhshow-suffix-application/PostScript: .ps" >> $TMP
     fi
 fi
 
