@@ -2,7 +2,7 @@
 /*
  * dropsbr.h -- definitions for maildrop-style files
  *
- * $Id$
+ * $Id: dropsbr.h,v 1.1.1.1 1999/04/30 18:08:34 doug Exp $
  */
 
 /*
@@ -28,10 +28,11 @@
  */
 
 /*
- * various formats to save message to a file
+ * various formats for maildrop files
  */
-#define MBOX_FORMAT 1
-#define MMDF_FORMAT 2
+#define OTHER_FORMAT 0
+#define MBOX_FORMAT  1
+#define MMDF_FORMAT  2
 
 #define	DRVRSN 3
 
@@ -46,7 +47,6 @@ struct drop {
  * prototypes
  */
 int mbx_open (char *, int, uid_t, gid_t, mode_t);
-int mbx_Xopen (char *, uid_t, gid_t, mode_t, int *);
 int mbx_read (FILE *, long, struct drop **, int);
 int mbx_write(char *, int, FILE *, int, long, long, off_t, int, int);
 int mbx_copy (char *, int, int, int, int, char *, int);
