@@ -2,14 +2,14 @@
 /*
  * fmt_scan.h -- definitions for fmt_scan()
  *
- * $Id$
+ * $Id: fmt_scan.h,v 1.2 2003/08/11 01:20:52 jchonig Exp $
  */
 
 /*
  * This structure describes an "interesting" component.  It holds
  * the name & text from the component (if found) and one piece of
  * auxilary info.  The structure for a particular component is located
- * by hashing the name and using it as an index into the ptr array
+ * by (open) hashing the name and using it as an index into the ptr array
  * "wantcomp".  All format entries that reference a particular component
  * point to its comp struct (so we only have to do component specific
  * processing once.  e.g., parse an address.).
@@ -34,16 +34,20 @@ struct comp {
  */
 #define	CT_ADDR       (1<<0)	/* referenced as address    */
 #define	CT_DATE       (1<<1)	/* referenced as date       */
-#define	CT_MYMBOX     (1<<2)	/* "mymbox" test being done */
-#define	CT_ADDRPARSE  (1<<3)	/* address parse being done */
+
+/*
+ * c_flags bits
+ */
+#define	CF_TRUE       (1<<0)	/* usually means component is present */
+#define	CF_PARSED     (1<<1)	/* address/date has been parsed */
+#define	CF_DATEFAB    (1<<2)	/* datefield fabricated */
 
 extern int fmt_norm;
 
 /*
- * hash table for deciding if a
- * component is "interesting"
+ * Hash table for deciding if a component is "interesting".
  */
-struct comp *wantcomp[128];
+extern struct comp *wantcomp[128];
 
 /* 
  * Hash function for component name.  The function should be
@@ -53,6 +57,9 @@ struct comp *wantcomp[128];
  */
 #define	CHASH(nm) (((((nm)[0]) - ((nm)[1])) & 0x1f) + (((nm)[2]) & 0x5f))
 
+/*
+ * Find a component in the hash table.
+ */
 #define FINDCOMP(comp,name) \
 		for (comp = wantcomp[CHASH(name)]; \
 		     comp && strcmp(comp->c_name,name); \
