@@ -2,7 +2,7 @@
 /*
  * mh.h -- main header file for all of nmh
  *
- * $Id: mh.h,v 1.2 2000/01/26 05:03:07 danh Exp $
+ * $Id: mh.h,v 1.5 2005/10/05 10:05:24 opk Exp $
  */
 
 #include <h/nmh.h>
@@ -21,6 +21,14 @@
 #define DMAXFOLDER     4	/* typical number of digits             */
 #define MAXFOLDER   1000	/* message increment                    */
 
+#ifndef FALSE
+#define FALSE 0
+#endif
+#ifndef TRUE
+#define TRUE 1
+#endif
+typedef unsigned char  boolean;  /* not int so we can pack in a structure */
+
 /*
  * user context/profile structure
  */
