@@ -2,7 +2,7 @@
 /*
  * prototypes.h -- various prototypes
  *
- * $Id: prototypes.h,v 1.4 2000/01/25 06:18:54 danh Exp $
+ * $Id: prototypes.h,v 1.12 2005/12/07 21:25:47 jon Exp $
  */
 
 /*
@@ -46,12 +46,13 @@ char *copy (char *, char *);
 char **copyip (char **, char **, int);
 void cpydata (int, int, char *, char *);
 void cpydgst (int, int, char *, char *);
-int decode_rfc2047 (char *, char *);
+int decode_rfc2047 (char *, char *, size_t);
 void discard (FILE *);
 int done (int);
+int ext_hook(char *, char *, char *);
 int fdcompare (int, int);
-int folder_addmsg (struct msgs **, char *, int, int, int);
-int folder_delmsgs (struct msgs *, int);
+int folder_addmsg (struct msgs **, char *, int, int, int, int, char *);
+int folder_delmsgs (struct msgs *, int, int);
 void folder_free (struct msgs *);
 int folder_pack (struct msgs **, int);
 struct msgs *folder_read (char *);
@@ -60,6 +61,7 @@ int gans (char *, struct swit *);
 char **getans (char *, struct swit *);
 int getanswer (char *);
 char **getarguments (char *, int, char **, int);
+char *get_charset();
 char *getcpy (char *);
 char *getfolder(int);
 int lkclose(int, char*);
@@ -81,6 +83,8 @@ char *m_scratch (char *, char *);
 char *m_tmpfil (char *);
 void m_unknown(FILE *);
 int makedir (char *);
+char *nmh_getpass(const char *);
+char *norm_charmap(char *);
 char *new_fs (char *, char *, char *);
 char *path(char *, int);
 int peekc(FILE *ib);
@@ -153,11 +157,13 @@ char *OfficialName(char *);
 /*
  * prototypes for some routines in uip
  */
-int annotate (char *, char *, char *, int, int);
+int annotate (char *, char *, char *, int, int, int, int);
+void annolist(char *, char *, char *, int);
+void annopreserve(int);
 int distout (char *, char *, char *);
 void replout (FILE *, char *, char *, struct msgs *, int,
 	int, char *, char *, char *);
-int sendsbr (char **, int, char *, struct stat *, int);
+int sendsbr (char **, int, char *, struct stat *, int, char *);
 int what_now (char *, int, int, char *, char *,
 	int, struct msgs *, char *, int, char *);
 
