@@ -2,7 +2,11 @@
 /*
  * hosts.c -- find out the official name of a host
  *
- * $Id: hosts.c,v 1.3 1999/10/15 22:38:56 doug Exp $
+ * $Id: hosts.c,v 1.6 2002/07/02 22:09:14 kenh Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 /*
@@ -13,7 +17,7 @@
  */
 
 #include <h/mh.h>
-#include <zotnet/mts/mts.h>
+#include <h/mts.h>
 #include <netdb.h>
 
 static struct host {
