@@ -2,7 +2,11 @@
 /*
  * context_find.c -- find an entry in the context/profile list
  *
- * $Id: context_find.c,v 1.1.1.1 1999/04/30 18:08:34 doug Exp $
+ * $Id: context_find.c,v 1.3 2002/11/18 18:25:02 jon Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -13,10 +17,6 @@ context_find (char *str)
 {
     struct node *np;
 
-    /* sanity check - check that context has been read */
-    if (defpath == NULL)
-	adios (NULL, "oops, context hasn't been read yet");
-
     for (np = m_defs; np; np = np->n_next)
 	if (!strcasecmp (np->n_name, str))
 	    return (np->n_field);
