@@ -2,7 +2,11 @@
 /*
  * folder_read.c -- initialize folder structure and read folder
  *
- * $Id: folder_read.c,v 1.1.1.1 1999/04/30 18:08:34 doug Exp $
+ * $Id: folder_read.c,v 1.4 2005/05/18 12:57:40 opk Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -53,7 +57,7 @@ folder_read (char *name)
     mp->numsel = 0;
     mp->nummsg = 0;
 
-    if (access (name, W_OK) == -1 || st.st_uid != getuid())
+    if (access (name, W_OK) == -1)
 	set_readonly (mp);
     prefix_len = strlen(BACKUP_PREFIX);
 
@@ -66,7 +70,7 @@ folder_read (char *name)
 	adios (NULL, "unable to allocate storage");
 
     while ((dp = readdir (dd))) {
-	if ((msgnum = m_atoi (dp->d_name))) {
+	if ((msgnum = m_atoi (dp->d_name)) && msgnum > 0) {
 	    /*
 	     * Check if we need to allocate more
 	     * temporary elements for message names.
