@@ -2,7 +2,11 @@
 /*
  * getans.c -- get an answer from the user and return a string array
  *
- * $Id$
+ * $Id: getans.c,v 1.2 2002/07/02 22:09:14 kenh Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -43,7 +47,7 @@ getans (char *prompt, struct swit *ansp)
 	    if (cp < &ansbuf[sizeof ansbuf - 1])
 		*cp++ = i;
 	}
-	*cp = 0;
+	*cp = '\0';
 	if (ansbuf[0] == '?' || cp == ansbuf) {
 	    printf ("Options are:\n");
 	    print_sw (ALL, ansp, "");
