@@ -2,11 +2,15 @@
 /*
  * m_getfld.c -- read/parse a message
  *
- * $Id: m_getfld.c,v 1.6 2000/01/26 21:35:43 danh Exp $
+ * $Id: m_getfld.c,v 1.10 2002/07/02 22:09:14 kenh Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
-#include <zotnet/mts/mts.h>
+#include <h/mts.h>
 
 /* This module has a long and checkered history.  First, it didn't burst
    maildrops correctly because it considered two CTRL-A:s in a row to be
@@ -730,7 +734,8 @@ matchc(int patln, char *pat, int strln, char *str)
 		while (pc != *str++)
 			if (str > es)
 				return 0;
-
+		if (str > es+1)
+			return 0;
 		sp = str; pp = pat;
 		while (pp < ep && *sp++ == *pp)
 			pp++;
