@@ -2,7 +2,11 @@
 /*
  * m_maildir.c -- get the path for the mail directory
  *
- * $Id$
+ * $Id: m_maildir.c,v 1.2 2002/07/02 22:09:14 kenh Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -47,9 +51,9 @@ m_mailpath (char *folder)
 	    && strcmp (folder, DOT)
 	    && strcmp (folder, DOTDOT)
 	    && strncmp (folder, PWD, NPWD)) {
-	strcpy (maildir, mailfold);		/* preserve... */
+	strncpy (maildir, mailfold, sizeof(maildir));	/* preserve... */
 	cp = getcpy (m_maildir (folder));
-	strcpy (mailfold, maildir);
+	strncpy (mailfold, maildir, sizeof(mailfold));
     } else {
 	cp = path (folder, TFOLDER);
     }
@@ -72,7 +76,7 @@ exmaildir (char *folder)
 	    && strcmp (folder, DOT)
 	    && strcmp (folder, DOTDOT)
 	    && strncmp (folder, PWD, NPWD))) {
-	strcpy (mailfold, folder);
+	strncpy (mailfold, folder, sizeof(mailfold));
 	return mailfold;
     }
 
@@ -83,9 +87,9 @@ exmaildir (char *folder)
 	    cp += strlen (cp);
 	}
 	cp = copy (pp, cp);
-    }
-    else
+    } else {
 	cp = copy (path ("./", TFOLDER), cp);
+    }
     if (cp[-1] != '/')
 	*cp++ = '/';
     strcpy (cp, folder);
