@@ -2,7 +2,11 @@
 /*
  * path.c -- return a pathname
  *
- * $Id$
+ * $Id: path.c,v 1.2 2002/07/02 22:09:14 kenh Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -44,10 +48,10 @@ expath (char *name, int flag)
     char buffer[BUFSIZ];
 
     if (flag == TSUBCWF) {
-	sprintf (buffer, "%s/%s", getfolder (1), name);
+	snprintf (buffer, sizeof(buffer), "%s/%s", getfolder (1), name);
 	name = m_mailpath (buffer);
 	compath (name);
-	sprintf (buffer, "%s/", m_maildir (""));
+	snprintf (buffer, sizeof(buffer), "%s/", m_maildir (""));
 	if (ssequal (buffer, name)) {
 	    cp = name;
 	    name = getcpy (name + strlen (buffer));
@@ -81,7 +85,7 @@ expath (char *name, int flag)
 	name += NCWD;
 
     if (strcmp (name, DOTDOT) == 0 || strcmp (name, PWD) == 0) {
-	sprintf (buffer, "%.*s", cp - pwds, pwds);
+	snprintf (buffer, sizeof(buffer), "%.*s", cp - pwds, pwds);
 	return getcpy (buffer);
     }
 
@@ -90,7 +94,7 @@ expath (char *name, int flag)
     else
 	cp = ep;
 
-    sprintf (buffer, "%.*s/%s", cp - pwds, pwds, name);
+    snprintf (buffer, sizeof(buffer), "%.*s/%s", cp - pwds, pwds, name);
     return getcpy (buffer);
 }
 
