@@ -2,7 +2,11 @@
 /*
  * seq_del.c -- delete message(s) from a sequence
  *
- * $Id$
+ * $Id: seq_del.c,v 1.2 2002/07/02 22:09:14 kenh Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -10,20 +14,32 @@
 
 /*
  * Delete all SELECTED messages from sequence
+ *
+ * If public ==  1, make sequence public.
+ * If public ==  0, make sequence private.
+ * If public == -1, leave the public/private bit alone for existing
+ *                  sequences.  For new sequences, set this bit based
+ *                  on its readonly status.
+ *
+ * If error, return 0, else return 1.
  */
 
 int
 seq_delsel (struct msgs *mp, char *cp, int public, int zero)
 {
-    int i, msgnum;
+    int i, msgnum, new_seq = 1;
 
     if (!seq_nameok (cp))
 	return 0;
 
-    /* find the index for the sequence */
+    /*
+     * Get the number for this sequence
+     */
     for (i = 0; mp->msgattrs[i]; i++) {
-	if (!strcmp (mp->msgattrs[i], cp))
+	if (!strcmp (mp->msgattrs[i], cp)) {
+	    new_seq = 0;
 	    break;
+	}
     }
 
     /*
@@ -31,24 +47,31 @@ seq_delsel (struct msgs *mp, char *cp, int public, int zero)
      * messages in this folder to the sequence.
      */
     if (zero) {
-	/* create the sequence, if necessary */
-	if (mp->msgattrs[i] == NULL) {
+	/*
+	 * create the sequence, if necessary
+	 */
+	if (new_seq) {
 	    if (i >= NUMATTRS) {
 		advise (NULL, "only %d sequences allowed (no room for %s)!", NUMATTRS, cp);
 		return 0;
 	    }
-	    mp->msgattrs[i] = getcpy (cp);
+	    if (!(mp->msgattrs[i] = strdup (cp))) {
+		advise (NULL, "strdup failed");
+		return 0;
+	    }
 	    mp->msgattrs[i + 1] = NULL;
 	}
-	/* now add sequence bit to all existing messages */
+	/*
+	 * now add sequence bit to all existing messages
+	 */
 	for (msgnum = mp->lowmsg; msgnum <= mp->hghmsg; msgnum++) {
-	    if (mp->msgstats[msgnum] & EXISTS)
+	    if (does_exist (mp, msgnum))
 		add_sequence (mp, i, msgnum);
 	    else
-		clear_sequence (mp, i, msgnum); /* probably not needed */
+		clear_sequence (mp, i, msgnum);
 	}
     } else {
-	if (mp->msgattrs[i] == NULL) {
+	if (new_seq) {
 	    advise (NULL, "no such sequence as %s", cp);
 	    return 0;
 	}
@@ -61,6 +84,24 @@ seq_delsel (struct msgs *mp, char *cp, int public, int zero)
 	if (is_selected (mp, msgnum))
 	    clear_sequence (mp, i, msgnum);
 
+    /*
+     * Set the public/private bit for this sequence.
+     */
+    if (public == 1)
+	make_seq_public (mp, i);
+    else if (public == 0)
+	make_seq_private (mp, i);
+    else if (new_seq) {
+	/*
+	 * If public == -1, then only set the
+	 * public/private bit for new sequences.
+	 */
+	if (is_readonly (mp))
+	    make_seq_private (mp, i);
+	else
+	    make_seq_public (mp, i);
+    }
+
     mp->msgflags |= SEQMOD;
     return 1;
 }
@@ -68,6 +109,8 @@ seq_delsel (struct msgs *mp, char *cp, int public, int zero)
 
 /*
  * Delete message from sequence.
+ *
+ * If error, return 0, else return 1.
  */
 
 int
