@@ -3,7 +3,11 @@
  * seq_read.c -- read the .mh_sequence file and
  *            -- initialize sequence information
  *
- * $Id: seq_read.c,v 1.1.1.1 1999/04/30 18:08:34 doug Exp $
+ * $Id: seq_read.c,v 1.4 2003/09/05 18:36:36 kenh Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -18,17 +22,13 @@ static void seq_private (struct msgs *);
 
 /*
  * Get the sequence information for this folder from
- * .mh_sequence (or equivalent specified in .mh_profile)
+ * .mh_sequences (or equivalent specified in .mh_profile)
  * or context file (for private sequences).
  */
 
 void
 seq_read (struct msgs *mp)
 {
-    /* sanity check - check that context has been read */
-    if (defpath == NULL)
-	adios (NULL, "oops, context hasn't been read yet");
-
     /*
      * Initialize the list of sequence names.  Go ahead and
      * add the "cur" sequence to the list of sequences.
@@ -73,7 +73,7 @@ seq_public (struct msgs *mp)
     /* get filename of sequence file */
     snprintf (seqfile, sizeof(seqfile), "%s/%s", mp->foldpath, mh_seq);
 
-    if ((fp = fopen (seqfile, "r")) == NULL)
+    if ((fp = lkfopen (seqfile, "r")) == NULL)
 	return;
 
     /* Use m_getfld to scan sequence file */
@@ -111,7 +111,7 @@ seq_public (struct msgs *mp)
 	break;	/* break from for loop */
     }
 
-    fclose (fp);
+    lkfclose (fp, seqfile);
 }
 
 
