@@ -2,13 +2,17 @@
 /*
  * ali.c -- list nmh mail aliases
  *
- * $Id: ali.c,v 1.4 2000/02/04 20:28:23 danh Exp $
+ * $Id: ali.c,v 1.7 2002/07/02 22:09:14 kenh Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
 #include <h/addrsbr.h>
 #include <h/aliasbr.h>
-#include <zotnet/mts/mts.h>
+#include <h/mts.h>
 
 /*
  * maximum number of names
