@@ -2,7 +2,11 @@
 /*
  * distsbr.c -- routines to do additional "dist-style" processing
  *
- * $Id$
+ * $Id: distsbr.c,v 1.2 2002/07/02 22:09:14 kenh Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -49,9 +53,9 @@ distout (char *drft, char *msgnam, char *backup)
 	    case FLDPLUS: 
 	    case FLDEOF: 
 		if (uprf (name, "distribute-"))
-		    sprintf (name, "%s%s", "Resent", &name[10]);
+		    snprintf (name, sizeof(name), "%s%s", "Resent", &name[10]);
 		if (uprf (name, "distribution-"))
-		    sprintf (name, "%s%s", "Resent", &name[12]);
+		    snprintf (name, sizeof(name), "%s%s", "Resent", &name[12]);
 		if (!uprf (name, "resent")) {
 		    advise (NULL, BADHDR, "draft", name);
 		    goto leave_bad;
@@ -135,7 +139,7 @@ ready_msg (char *msgnam)
     if ((ifp = fopen (msgnam, "r")) == NULL)
 	adios (msgnam, "unable to open message");
 
-    strcpy (tmpfil, m_tmpfil ("dist"));
+    strncpy (tmpfil, m_tmpfil ("dist"), sizeof(tmpfil));
     if ((hdrfd = open (tmpfil, O_RDWR | O_CREAT | O_TRUNC, 0600)) == NOTOK)
 	adios (tmpfil, "unable to re-open temporary file");
     if ((out = dup (hdrfd)) == NOTOK
@@ -165,7 +169,7 @@ ready_msg (char *msgnam)
 	    case BODYEOF: 
 		fclose (ofp);
 
-		strcpy (tmpfil, m_tmpfil ("dist"));
+		strncpy (tmpfil, m_tmpfil ("dist"), sizeof(tmpfil));
 		if ((txtfd = open (tmpfil, O_RDWR | O_CREAT | O_TRUNC, 0600)) == NOTOK)
 		    adios (tmpfil, "unable to open temporary file");
 		if ((out = dup (txtfd)) == NOTOK
