@@ -13,7 +13,7 @@
  * makes no warranty about the software, its performance or its conformity to
  * any specification.
  *
- *  $Id: flist.c,v 1.3 1999/07/16 01:32:28 danh Exp $
+ *  $Id: flist.c,v 1.6 2005/11/02 17:22:27 opk Exp $
  */
 
 #include <h/mh.h>
@@ -58,7 +58,7 @@ static struct swit switches[] = {
 #define VERSIONSW	13
     { "version", 0 },
 #define HELPSW          14
-    { "help", 4 },
+    { "help", 0 },
     { NULL, 0 }
 };
 
@@ -401,7 +401,7 @@ BuildFolderList(char *dirName, int searchdepth)
 void
 BuildFolderListRecurse(char *dirName, struct stat *s, int searchdepth)
 {
-    char *base, name[PATH_MAX];
+    char *base, *n, name[PATH_MAX];
     int nlinks;
     DIR *dir;
     struct dirent *dp;
@@ -432,6 +432,12 @@ BuildFolderListRecurse(char *dirName, struct stat *s, int searchdepth)
 	}
 	if (dp->d_name[0] == '.')
 	    continue;
+	/* Check to see if the name of the file is a number
+	 * if it is, we assume it's a mail file and skip it
+	 */
+	for (n = dp->d_name; *n && isdigit(*n); n++);
+	if (!*n)
+	    continue;
 	strncpy (name, base, sizeof(name) - 2);
 	if (*base)
 	    strcat(name, "/");
@@ -697,10 +703,6 @@ do_readonly_folders (void)
     char atrcur[BUFSIZ];
     register struct node *np;
 
-    /* sanity check - check that context has been read */
-    if (defpath == NULL)
-	adios (NULL, "oops, context hasn't been read yet");
-
     snprintf (atrcur, sizeof(atrcur), "atr-%s-", current);
     atrlen = strlen (atrcur);
 
