@@ -2,7 +2,11 @@
 /*
  * fmtdump.c -- compile format file and dump out instructions
  *
- * $Id: fmtdump.c,v 1.3 1999/09/12 13:50:12 doug Exp $
+ * $Id: fmtdump.c,v 1.6 2003/08/11 01:20:52 jchonig Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -18,7 +22,7 @@ static struct swit switches[] = {
 #define VERSIONSW           2
     { "version", 0 },
 #define	HELPSW              3
-    { "help", 4 },
+    { "help", 0 },
     { NULL, 0 }
 };
 
@@ -35,6 +39,7 @@ static int findlabel(struct format *);
 static void assignlabel(struct format *);
 static char *f_typestr(int);
 static char *c_typestr(int);
+static char *c_flagsstr(int);
 static void litputs(char *);
 static void litputc(char);
 
@@ -159,7 +164,7 @@ dumpone(struct format *fmt)
 		if (fmt->f_comp->c_type)
 			printf(", c_type %s", c_typestr(fmt->f_comp->c_type));
 		if (fmt->f_comp->c_flags)
-			printf(", c_flags %d", fmt->f_comp->c_flags);
+			printf(", c_flags %s", c_flagsstr(fmt->f_comp->c_flags));
 		break;
 
 	case FT_LV_SEC:
@@ -191,7 +196,7 @@ dumpone(struct format *fmt)
 		if (fmt->f_comp->c_type)
 			printf(", c_type %s", c_typestr(fmt->f_comp->c_type));
 		if (fmt->f_comp->c_flags)
-			printf(", c_flags %d", fmt->f_comp->c_flags);
+			printf(", c_flags %s", c_flagsstr(fmt->f_comp->c_flags));
 		break;
 
 	case FT_LS_ADDR:
@@ -213,7 +218,7 @@ dumpone(struct format *fmt)
 		if (fmt->f_comp->c_type)
 			printf(", c_type %s", c_typestr(fmt->f_comp->c_type));
 		if (fmt->f_comp->c_flags)
-			printf(", c_flags %d", fmt->f_comp->c_flags);
+			printf(", c_flags %s", c_flagsstr(fmt->f_comp->c_flags));
 		break;
 
 	case FT_COMPF:
@@ -224,7 +229,7 @@ dumpone(struct format *fmt)
 		if (fmt->f_comp->c_type)
 			printf(", c_type %s", c_typestr(fmt->f_comp->c_type));
 		if (fmt->f_comp->c_flags)
-			printf(", c_flags %d", fmt->f_comp->c_flags);
+			printf(", c_flags %s", c_flagsstr(fmt->f_comp->c_flags));
 		break;
 
 	case FT_STRF:
@@ -448,19 +453,35 @@ c_typestr(int t)
 	static char buf[64];
 
 	buf[0] = '\0';
-	if (t & ~(CT_ADDR|CT_DATE|CT_MYMBOX|CT_ADDRPARSE))
+	if (t & ~(CT_ADDR|CT_DATE))
 		printf(buf, "0x%x ", t);
 	strcat(buf, "<");
 	i = 0;
 	FNORD(CT_ADDR, "ADDR");
 	FNORD(CT_DATE, "DATE");
-	FNORD(CT_MYMBOX, "MYMBOX");
-	FNORD(CT_ADDRPARSE, "ADDRPARSE");
 	strcat(buf, ">");
 	return(buf);
-#undef FNORD
 }
 
+static char *
+c_flagsstr(int t)
+{
+	register int i;
+	static char buf[64];
+
+	buf[0] = '\0';
+	if (t & ~(CF_TRUE|CF_PARSED|CF_DATEFAB))
+		printf(buf, "0x%x ", t);
+	strcat(buf, "<");
+	i = 0;
+	FNORD(CF_TRUE, "TRUE");
+	FNORD(CF_PARSED, "PARSED");
+	FNORD(CF_DATEFAB, "DATEFAB");
+	strcat(buf, ">");
+	return(buf);
+}
+#undef FNORD
+
 static void
 litputs(char *s)
 {
