@@ -4,7 +4,11 @@
  *             -- push/pop a folder onto/from the folder stack
  *             -- list the folder stack
  *
- * $Id: folder.c,v 1.2 1999/07/16 01:31:56 danh Exp $
+ * $Id: folder.c,v 1.6 2003/09/30 16:58:00 gbburkhardt Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -58,12 +62,10 @@ static struct swit switches[] = {
 #define VERSIONSW      22
     { "version", 0 },
 #define	HELPSW         23
-    { "help", 4 },
+    { "help", 0 },
     { NULL, 0 }
 };
 
-extern int errno;
-
 static int fshort   = 0;	/* output only folder names                 */
 static int fcreat   = 0;	/* should we ask to create new folders?     */
 static int fpack    = 0;	/* are we packing the folder?               */
@@ -814,10 +816,6 @@ readonly_folders (void)
     char atrcur[BUFSIZ];
     register struct node *np;
 
-    /* sanity check - check that context has been read */
-    if (defpath == NULL)
-	adios (NULL, "oops, context hasn't been read yet");
-
     snprintf (atrcur, sizeof(atrcur), "atr-%s-", current);
     atrlen = strlen (atrcur);
 
