@@ -2,7 +2,11 @@
 /*
  * mhbuild.c -- expand/translate MIME composition files
  *
- * $Id: mhbuild.c,v 1.3 2000/02/04 20:28:24 danh Exp $
+ * $Id: mhbuild.c,v 1.8 2003/09/30 16:58:43 gbburkhardt Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -11,8 +15,8 @@
 #include <h/md5.h>
 #include <errno.h>
 #include <signal.h>
-#include <zotnet/mts/mts.h>
-#include <zotnet/tws/tws.h>
+#include <h/mts.h>
+#include <h/tws.h>
 #include <h/mime.h>
 #include <h/mhparse.h>
 #include <h/mhcachesbr.h>
@@ -64,8 +68,6 @@ static struct swit switches[] = {
 };
 
 
-extern int errno;
-
 /* mhbuildsbr.c */
 extern int checksw;
 extern char *tmp;	/* directory to place temp files */
