@@ -2,7 +2,11 @@
 /*
  * mhbuildsbr.c -- routines to expand/translate MIME composition files
  *
- * $Id: mhbuildsbr.c,v 1.4 1999/09/12 13:50:12 doug Exp $
+ * $Id: mhbuildsbr.c,v 1.9 2003/09/30 16:58:43 gbburkhardt Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 /*
@@ -19,8 +23,8 @@
 #include <h/md5.h>
 #include <errno.h>
 #include <signal.h>
-#include <zotnet/mts/mts.h>
-#include <zotnet/tws/tws.h>
+#include <h/mts.h>
+#include <h/tws.h>
 #include <h/mime.h>
 #include <h/mhparse.h>
 
@@ -40,8 +44,6 @@
 #endif
 
 
-extern int errno;
-
 extern int debugsw;
 extern int verbosw;
 
