@@ -2,7 +2,11 @@
 /*
  * mhcachesbr.c -- routines to manipulate the MIME content cache
  *
- * $Id: mhcachesbr.c,v 1.2 1999/09/12 13:50:12 doug Exp $
+ * $Id: mhcachesbr.c,v 1.7 2003/09/30 16:58:43 gbburkhardt Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -12,8 +16,8 @@
 #include <errno.h>
 #include <setjmp.h>
 #include <signal.h>
-#include <zotnet/mts/mts.h>
-#include <zotnet/tws/tws.h>
+#include <h/mts.h>
+#include <h/tws.h>
 #include <h/mime.h>
 #include <h/mhparse.h>
 #include <h/mhcachesbr.h>
@@ -33,8 +37,6 @@
 # include <sys/wait.h>
 #endif
 
-
-extern int errno;
 extern int debugsw;
 
 extern pid_t xpid;	/* mhshowsbr.c or mhbuildsbr.c */
