@@ -3,20 +3,23 @@
  * mhfree.c -- routines to free the data structures used to
  *          -- represent MIME messages
  *
- * $Id$
+ * $Id: mhfree.c,v 1.4 2003/09/30 16:58:43 gbburkhardt Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
 #include <errno.h>
-#include <h/mhn.h>
+#include <h/mime.h>
 #include <h/mhparse.h>
 
-extern int errno;
-
 /*
  * prototypes
  */
 void free_content (CT);
+void free_header (CT);
 void free_ctinfo (CT);
 void free_encoding (CT, int);
 
@@ -39,6 +42,11 @@ free_content (CT ct)
     if (!ct)
 	return;
 
+    /*
+     * free all the header fields
+     */
+    free_header (ct);
+
     if (ct->c_partno)
 	free (ct->c_partno);
 
@@ -111,6 +119,32 @@ free_content (CT ct)
 }
 
 
+/*
+ * Free the linked list of header fields
+ * for this content.
+ */
+
+void
+free_header (CT ct)
+{
+    HF hp1, hp2;
+
+    hp1 = ct->c_first_hf;
+    while (hp1) {
+	hp2 = hp1->next;
+
+	free (hp1->name);
+	free (hp1->value);
+	free (hp1);
+
+	hp1 = hp2;
+    }
+
+    ct->c_first_hf = NULL;
+    ct->c_last_hf  = NULL;
+}
+
+
 void
 free_ctinfo (CT ct)
 {
@@ -235,6 +269,7 @@ free_encoding (CT ct, int toplevel)
 	if (ce->ce_unlink)
 	    unlink (ce->ce_file);
 	free (ce->ce_file);
+	ce->ce_file = NULL;
     }
 
     if (toplevel) {
