@@ -2,11 +2,18 @@
 /*
  * mhl.c -- the nmh message listing program
  *
- * $Id$
+ * $Id: mhl.c,v 1.4 2002/07/02 22:09:14 kenh Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
 
+/* prototype from mhlsbr.c */
+int mhl (int, char **);
+
 
 int
 main (int argc, char **argv)
@@ -14,7 +21,7 @@ main (int argc, char **argv)
 #ifdef LOCALE
     setlocale(LC_ALL, "");
 #endif
-    done (mhl (argc, argv));
+    return done (mhl (argc, argv));
 }
 
 
