@@ -3,7 +3,11 @@
  * mhlistsbr.c -- routines to list information about the
  *             -- contents of MIME messages
  *
- * $Id: mhlistsbr.c,v 1.1.1.1 1999/04/30 18:08:35 doug Exp $
+ * $Id: mhlistsbr.c,v 1.6 2003/09/30 16:58:43 gbburkhardt Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -11,13 +15,11 @@
 #include <h/signals.h>
 #include <errno.h>
 #include <signal.h>
-#include <zotnet/mts/mts.h>
-#include <zotnet/tws/tws.h>
+#include <h/mts.h>
+#include <h/tws.h>
 #include <h/mime.h>
 #include <h/mhparse.h>
 
-extern int errno;
-
 /* mhmisc.c */
 int part_ok (CT, int);
 int type_ok (CT, int);
