@@ -2,7 +2,11 @@
 /*
  * mhshowsbr.c -- routines to display the contents of MIME messages
  *
- * $Id: mhshowsbr.c,v 1.5 2000/04/06 00:11:50 danh Exp $
+ * $Id: mhshowsbr.c,v 1.11 2003/09/30 16:58:43 gbburkhardt Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -12,8 +16,8 @@
 #include <errno.h>
 #include <setjmp.h>
 #include <signal.h>
-#include <zotnet/mts/mts.h>
-#include <zotnet/tws/tws.h>
+#include <h/mts.h>
+#include <h/tws.h>
 #include <h/mime.h>
 #include <h/mhparse.h>
 
@@ -31,7 +35,6 @@
 # define siglongjmp(env,val) longjmp(env,val)
 #endif
 
-extern int errno;
 extern int debugsw;
 
 int pausesw  = 1;
@@ -136,7 +139,9 @@ show_single_message (CT ct, char *form)
     union wait status;
 #endif
 
-    umask (ct->c_umask);
+    /* Allow user executable bit so that temporary directories created by
+     * the viewer (e.g., lynx) are going to be accessible */
+    umask (ct->c_umask & ~(0100));
 
     /*
      * If you have a format file, then display
