@@ -2,7 +2,11 @@
 /*
  * mhtest.c -- test harness for MIME routines
  *
- * $Id: mhtest.c,v 1.3 2000/02/04 20:28:24 danh Exp $
+ * $Id: mhtest.c,v 1.8 2003/09/30 16:58:43 gbburkhardt Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -11,8 +15,8 @@
 #include <h/md5.h>
 #include <errno.h>
 #include <signal.h>
-#include <zotnet/mts/mts.h>
-#include <zotnet/tws/tws.h>
+#include <h/mts.h>
+#include <h/tws.h>
 #include <h/mime.h>
 #include <h/mhparse.h>
 #include <h/mhcachesbr.h>
@@ -63,8 +67,6 @@ static struct swit switches[] = {
 };
 
 
-extern int errno;
-
 int ebcdicsw = 0;	/* hack for linking purposes */
 
 /* mhparse.c */
