@@ -2,12 +2,16 @@
 /*
  * msgchk.c -- check for mail
  *
- * $Id: msgchk.c,v 1.5 2000/03/17 20:11:04 danh Exp $
+ * $Id: msgchk.c,v 1.11 2005/01/27 16:34:21 opk Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
-#include <zotnet/mts/mts.h>
-#include <zotnet/tws/tws.h>
+#include <h/mts.h>
+#include <h/tws.h>
 #include <pwd.h>
 
 #ifdef POP
@@ -42,6 +46,12 @@
 # define KPOPminc(a)  0
 #endif
 
+#ifndef CYRUS_SASL
+# define SASLminc(a) (a)
+#else
+# define SASLminc(a)  0
+#endif
+
 static struct swit switches[] = {
 #define	DATESW                   0
     { "date", 0 },
@@ -71,6 +81,12 @@ static struct swit switches[] = {
     { "snoop", -5 },
 #define KPOPSW                  13
     { "kpop", KPOPminc (-4) },
+#define SASLSW                  14
+    { "sasl", SASLminc(-4) },
+#define SASLMECHSW		15
+    { "saslmech", SASLminc(-5) },
+#define PROXYSW 		16
+    { "proxy command", POPminc(-5) },
     { NULL, 0 }
 };
 
@@ -101,7 +117,7 @@ static int donote (char *, int);
 static int checkmail (char *, char *, int, int, int);
 
 #ifdef POP
-static int remotemail (char *, char *, int, int, int, int, int);
+static int remotemail (char *, char *, char *, int, int, int, int, int, int, char *);
 #endif
 
 
@@ -110,10 +126,11 @@ main (int argc, char **argv)
 {
     int datesw = 1, notifysw = NT_ALL;
     int rpop, status = 0;
-    int kpop = 0;
+    int kpop = 0, sasl = 0;
     int snoop = 0, vecp = 0;
     uid_t uid;
-    char *cp, *host = NULL, *user, buf[BUFSIZ];
+    char *cp, *host = NULL, *user, *proxy = NULL; 
+    char buf[BUFSIZ], *saslmech = NULL; 
     char **argp, **arguments, *vec[MAXVEC];
     struct passwd *pw;
 
@@ -214,6 +231,20 @@ main (int argc, char **argv)
 		case SNOOPSW:
 		    snoop++;
 		    continue;
+
+		case SASLSW:
+		    sasl++;
+		    continue;
+		
+		case SASLMECHSW:
+		    if (!(saslmech = *argp++) || *saslmech == '-')
+			adios (NULL, "missing argument to %s", argp[-2]);
+		    continue;
+
+		case PROXYSW:
+		    if (!(proxy = *argp++) || *proxy == '-')
+			adios (NULL, "missing argument to %s", argp[-2]);
+		    continue;
 	    }
 	}
 	if (vecp >= MAXVEC-1)
@@ -263,10 +294,12 @@ main (int argc, char **argv)
 	    kpop = 1;
 	}
 	if (vecp == 0) {
-	    status = remotemail (host, user, rpop, kpop, notifysw, 1, snoop);
+	    status = remotemail (host, user, proxy, rpop, kpop, notifysw, 1,
+				 snoop, sasl, saslmech);
 	} else {
 	    for (vecp = 0; vec[vecp]; vecp++)
-		status += remotemail (host, vec[vecp], rpop, kpop, notifysw, 0, snoop);
+		status += remotemail (host, vec[vecp], proxy, rpop, kpop,
+		                      notifysw, 0, snoop, sasl, saslmech);
 	}
     } else {
 #endif /* POP */
@@ -387,20 +420,21 @@ checkmail (char *user, char *home, int datesw, int notifysw, int personal)
 extern char response[];
 
 static int
-remotemail (char *host, char *user, int rpop, int kpop, int notifysw, int personal, int snoop)
+remotemail (char *host, char *user, char *proxy, int rpop, int kpop, int notifysw, int personal, int snoop, int sasl, char *saslmech)
 {
     int nmsgs, nbytes, status;
     char *pass = NULL;
 
     if (user == NULL)
 	user = getusername ();
-    if (kpop || (rpop > 0))
+    if (kpop || sasl || (rpop > 0))
 	pass = getusername ();
     else
 	ruserpass (host, &user, &pass);
 
     /* open the POP connection */
-    if (pop_init (host, user, pass, snoop, kpop ? 1 : rpop, kpop) == NOTOK
+    if (pop_init (host, user, pass, proxy, snoop, kpop ? 1 : rpop, kpop,
+		  sasl, saslmech) == NOTOK
 	    || pop_stat (&nmsgs, &nbytes) == NOTOK	/* check for messages  */
 	    || pop_quit () == NOTOK) {			/* quit POP connection */
 	advise (NULL, "%s", response);
