@@ -2,7 +2,11 @@
 /*
  * mshcmds.c -- command handlers in msh
  *
- * $Id: mshcmds.c,v 1.6 2000/02/04 20:28:24 danh Exp $
+ * $Id: mshcmds.c,v 1.12 2003/09/30 16:58:43 gbburkhardt Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -10,15 +14,14 @@
 #include <h/dropsbr.h>
 #include <h/fmt_scan.h>
 #include <h/scansbr.h>
-#include <zotnet/tws/tws.h>
-#include <zotnet/mts/mts.h>
+#include <h/tws.h>
+#include <h/mts.h>
 #include <errno.h>
 #include <setjmp.h>
 #include <signal.h>
 #include <h/msh.h>
 #include <h/picksbr.h>
 
-extern int errno;
 
 static char delim3[] = "-------";	/* from burst.c */
 
@@ -2387,7 +2390,6 @@ showcmd (char **args)
 	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
 	    if (is_selected (mp, msgnum) && is_nontext (msgnum)) {
 		proc = showmimeproc;
-		vec[vecp++] = "-show";
 		vec[vecp++] = "-file";
 		vec[vecp] = NULL;
 		goto finish;
@@ -3006,7 +3008,6 @@ process (int msgnum, char *proc, int vecp, char **vec)
     strncpy (tmpfil, m_scratch ("", invo_name), sizeof(tmpfil));
     if ((out = fopen (tmpfil, "w")) == NULL) {
 	int olderr;
-	extern int errno;
 	char newfil[80];
 
 	olderr = errno;
