@@ -2,11 +2,15 @@
 /*
  * pick.c -- search for messages by content
  *
- * $Id: pick.c,v 1.3 2000/02/04 20:28:24 danh Exp $
+ * $Id: pick.c,v 1.6 2003/09/30 14:19:20 gbburkhardt Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
-#include <zotnet/tws/tws.h>
+#include <h/tws.h>
 #include <h/picksbr.h>
 
 /*
@@ -68,7 +72,7 @@ static struct swit switches[] = {
     { NULL, 0 }
 };
 
-static int listsw = 0;
+static int listsw = -1;
 
 
 int
@@ -111,6 +115,7 @@ main (int argc, char **argv)
 	    switch (smatch (cp, switches)) {
 	    case AMBIGSW: 
 		ambigsw (cp, switches);
+		listsw = 0;	/* HACK */
 		done (1);
 	    case UNKWNSW: 
 		adios (NULL, "-%s unknown", cp);
@@ -123,6 +128,7 @@ main (int argc, char **argv)
 		done (1);
 	    case VERSIONSW:
 		print_version(invo_name);
+		listsw = 0;	/* HACK */
 		done (1);
 
 	    case CCSW: 
@@ -159,7 +165,6 @@ main (int argc, char **argv)
 		if (seqp >= NUMATTRS)
 		    adios (NULL, "too many sequences (more than %d) specified", NUMATTRS);
 		seqs[seqp++] = cp;
-		listsw = 0;
 		continue;
 	    case PUBLSW: 
 		publicsw = 1;
@@ -175,7 +180,7 @@ main (int argc, char **argv)
 		continue;
 
 	    case LISTSW: 
-		listsw++;
+		listsw = 1;
 		continue;
 	    case NLISTSW: 
 		listsw = 0;
@@ -236,10 +241,10 @@ main (int argc, char **argv)
 
     /*
      * If we aren't saving the results to a sequence,
-     * we need to list the results.
+     * we default to list the results.
      */
-    if (seqp == 0)
-	listsw++;
+    if (listsw == -1)
+	listsw = !seqp;
 
     if (publicsw == 1 && is_readonly(mp))
 	adios (NULL, "folder %s is read-only, so -public not allowed", folder);
