@@ -2,11 +2,15 @@
 /*
  * picksbr.c -- routines to help pick along...
  *
- * $Id: picksbr.c,v 1.5 2000/01/26 21:35:43 danh Exp $
+ * $Id: picksbr.c,v 1.7 2002/07/02 22:09:15 kenh Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
-#include <zotnet/tws/tws.h>
+#include <h/tws.h>
 #include <h/picksbr.h>
 
 #ifdef TIME_WITH_SYS_TIME
