@@ -2,7 +2,11 @@
 /*
  * rcvstore.c -- asynchronously add mail to a folder
  *
- * $Id: rcvstore.c,v 1.4 2000/02/04 20:28:24 danh Exp $
+ * $Id: rcvstore.c,v 1.10 2004/11/19 05:06:16 jon Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -10,7 +14,7 @@
 #include <h/signals.h>
 #include <errno.h>
 #include <signal.h>
-#include <zotnet/mts/mts.h>
+#include <h/mts.h>
 
 static struct swit switches[] = {
 #define CRETSW         0
@@ -38,7 +42,6 @@ static struct swit switches[] = {
     { NULL, 0 }
 };
 
-extern int errno;
 
 /*
  * name of temporary file to store incoming message
@@ -199,7 +202,7 @@ main (int argc, char **argv)
      * Link message into folder, and possibly add
      * to the Unseen-Sequence's.
      */
-    if ((msgnum = folder_addmsg (&mp, tmpfilenam, 0, unseensw, 0)) == -1)
+    if ((msgnum = folder_addmsg (&mp, tmpfilenam, 0, unseensw, 0, 0, (char *)0)) == -1)
 	done (1);
 
     /*
