@@ -2,13 +2,18 @@
 /*
  * replsbr.c -- routines to help repl along...
  *
- * $Id$
+ * $Id: replsbr.c,v 1.6 2005/10/05 10:05:24 opk Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
 #include <h/addrsbr.h>
 #include <h/fmt_scan.h>
 #include <sys/file.h>		/* L_SET */
+#include <errno.h>
 
 extern short ccto;		/* from repl.c */
 extern short cccc;
@@ -22,15 +27,14 @@ static char *dfhost = NULL;
 
 static struct mailname mq = { NULL };
 
+/*
+ * Buffer size for content part of header fields.
+ * We want this to be large enough so that we don't
+ * do a lot of extra FLDPLUS calls on m_getfld but
+ * small enough so that we don't snarf the entire
+ * message body when we're not going to use any of it.
+ */
 #define SBUFSIZ 256		
-				/* buffer size for content part of header
-				 * fields.  We want this to be large
-				 * enough so that we don't do a lot of
-				 * extra FLDPLUS calls on m_getfld but
-				 * small enough so that we don't snarf
-				 * the entire message body when we're
-				 * not going to use any of it.
-				 */
 
 static struct format *fmt;
 
@@ -67,28 +71,29 @@ void
 replout (FILE *inb, char *msg, char *drft, struct msgs *mp, int outputlinelen,
 	int mime, char *form, char *filter, char *fcc)
 {
-    register int state;
-    register int i;
+    register int state, i;
     register struct comp *cptr;
     register char *tmpbuf;
     register char **nxtbuf;
-    register struct comp **savecomp;
-    FILE *out;
-    char name[NAMESZ];
-    char *scanl;
-    int	char_read = 0;
-    char *cp;
-    int format_len;
     register char **ap;
+    register struct comp **savecomp;
+    int	char_read = 0, format_len, mask;
+    char name[NAMESZ], *scanl, *cp;
+    FILE *out;
 
-    umask(~m_gmprot());
+    mask = umask(~m_gmprot());
     if ((out = fopen (drft, "w")) == NULL)
 	adios (drft, "unable to create");
 
+    umask(mask);
+
     /* get new format string */
     cp = new_fs (form, NULL, NULL);
     format_len = strlen (cp);
+
+    /* compile format string */
     ncomps = fmt_compile (cp, &fmt) + 1;
+
     if (!(nxtbuf = compbuffers = (char **)
 	    calloc((size_t) ncomps, sizeof(char *))))
 	adios (NULL, "unable to allocate component buffers");
@@ -162,13 +167,14 @@ replout (FILE *inb, char *msg, char *drft, struct msgs *mp, int outputlinelen,
 				tmpbuf = *nxtbuf++;
 			    } else {
 				i = strlen (cp = cptr->c_text) - 1;
-				if (cp[i] == '\n')
+				if (cp[i] == '\n') {
 				    if (cptr->c_type & CT_ADDR) {
 					cp[i] = '\0';
 					cp = add (",\n\t", cp);
 				    } else {
 					cp = add ("\t", cp);
 				    }
+				}
 				cptr->c_text = add (tmpbuf, cp);
 			    }
 			    while (state == FLDPLUS) {
@@ -242,19 +248,24 @@ finished:
      * or add mhn directives
      */
     if (filter) {
+	fflush(out);
+	if (ferror (out))
+	    adios (drft, "error writing");
+	
 	replfilter (inb, out, filter);
     } else if (mime && mp) {
 	    fprintf (out, "#forw [original message] +%s %s\n",
 		     mp->foldpath, m_name (mp->lowsel));
     }
 
+    fflush(out);
     if (ferror (out))
 	adios (drft, "error writing");
     fclose (out);
 
     /* return dynamically allocated buffers */
     free (scanl);
-    for (nxtbuf = compbuffers, i = ncomps; cptr = *savecomp++; nxtbuf++, i--)
+    for (nxtbuf = compbuffers, i = ncomps; (cptr = *savecomp++); nxtbuf++, i--)
 	free (cptr->c_text);	/* if not nxtbuf, nxtbuf already freed */
     while ( i-- > 0)
         free (*nxtbuf++);	/* free unused nxtbufs */
@@ -336,9 +347,9 @@ formataddr (char *orig, char *str)
     }
 
     /* concatenate all the new addresses onto 'buf' */
-    for (isgroup = 0; cp = getname (str); ) {
+    for (isgroup = 0; (cp = getname (str)); ) {
 	if ((mp = getm (cp, dfhost, dftype, AD_NAME, error)) == NULL) {
-	    sprintf (baddr, "\t%s -- %s\n", cp, error);
+	    snprintf (baddr, sizeof(baddr), "\t%s -- %s\n", cp, error);
 	    badaddrs = add (baddr, badaddrs);
 	    continue;
 	}
@@ -390,7 +401,7 @@ insert (struct mailname *np)
 	return 0;
 
     if (querysw) {
-	sprintf (buffer, "Reply to %s? ", adrformat (np));
+	snprintf (buffer, sizeof(buffer), "Reply to %s? ", adrformat (np));
 	if (!gans (buffer, anoyes))
 	return 0;
     }
@@ -407,6 +418,8 @@ insert (struct mailname *np)
 
 /*
  * Call the mhlproc
+ *
+ * This function expects that argument out has been fflushed by the caller.
  */
 
 static void
@@ -414,6 +427,7 @@ replfilter (FILE *in, FILE *out, char *filter)
 {
     int	pid;
     char *mhl;
+    char *errstr;
 
     if (filter == NULL)
 	return;
@@ -425,7 +439,6 @@ replfilter (FILE *in, FILE *out, char *filter)
 
     rewind (in);
     lseek (fileno(in), (off_t) 0, SEEK_SET);
-    fflush (out);
 
     switch (pid = vfork ()) {
 	case NOTOK: 
@@ -437,8 +450,12 @@ replfilter (FILE *in, FILE *out, char *filter)
 	    closefds (3);
 
 	    execlp (mhlproc, mhl, "-form", filter, "-noclear", NULL);
-	    fprintf (stderr, "unable to exec ");
-	    perror (mhlproc);
+	    errstr = strerror(errno);
+	    write(2, "unable to exec ", 15);
+	    write(2, mhlproc, strlen(mhlproc));
+	    write(2, ": ", 2);
+	    write(2, errstr, strlen(errstr));
+	    write(2, "\n", 1);
 	    _exit (-1);
 
 	default: 
