@@ -2,7 +2,11 @@
 /*
  * rmm.c -- remove a message(s)
  *
- * $Id: rmm.c,v 1.2 1999/07/16 01:27:07 danh Exp $
+ * $Id: rmm.c,v 1.5 2002/08/23 20:37:01 jon Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -21,7 +25,7 @@ static struct swit switches[] = {
 #define VERSIONSW     2
     { "version", 0 },
 #define	HELPSW        3
-    { "help", 4 },
+    { "help", 0 },
     { NULL, 0 }
 };
 
@@ -141,7 +145,7 @@ main (int argc, char **argv)
     }
 
     /* "remove" the SELECTED messages */
-    folder_delmsgs (mp, unlink_msgs);
+    folder_delmsgs (mp, unlink_msgs, 0);
 
     seq_save (mp);		/* synchronize message sequences  */
     context_replace (pfolder, folder);	/* update current folder   */
