@@ -2,7 +2,11 @@
 /*
  * send.c -- send a composed message
  *
- * $Id: send.c,v 1.3 2000/02/04 20:28:24 danh Exp $
+ * $Id: send.c,v 1.7 2003/09/30 16:58:43 gbburkhardt Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -11,6 +15,12 @@
 #include <signal.h>
 
 
+#ifndef CYRUS_SASL
+# define SASLminc(a) (a)
+#else /* CYRUS_SASL */
+# define SASLminc(a)  0
+#endif /* CYRUS_SASL */
+
 static struct swit switches[] = {
 #define	ALIASW                 0
     { "alias aliasfile", 0 },
@@ -86,6 +96,14 @@ static struct swit switches[] = {
     { "server host", -6 },
 #define	SNOOPSW               36
     { "snoop", -5 },
+#define SASLSW                37
+    { "sasl", SASLminc(-4) },
+#define SASLMECHSW            38
+    { "saslmech", SASLminc(-5) },
+#define USERSW                39
+    { "user", SASLminc(-4) },
+#define ATTACHSW              40
+    { "attach", 6 },
     { NULL, 0 }
 };
 
@@ -111,7 +129,6 @@ extern char *altmsg;		/*  .. */
 extern char *annotext;
 extern char *distfile;
 
-extern int   errno;
 
 int
 main (int argc, char **argv)
@@ -124,6 +141,7 @@ main (int argc, char **argv)
     char *msgs[MAXARGS], *vec[MAXARGS];
     struct msgs *mp;
     struct stat st;
+    char	*attach = (char *)0;	/* header field name for attachments */
 #ifdef UCI
     FILE *fp;
 #endif /* UCI */
@@ -241,6 +259,7 @@ main (int argc, char **argv)
 		case SENDSW: 
 		case SOMLSW: 
 		case SNOOPSW: 
+		case SASLSW:
 		    vec[vecp++] = --cp;
 		    continue;
 
@@ -249,11 +268,18 @@ main (int argc, char **argv)
 		case WIDTHSW: 
 		case CLIESW: 
 		case SERVSW: 
+		case SASLMECHSW:
+		case USERSW:
 		    vec[vecp++] = --cp;
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    vec[vecp++] = cp;
 		    continue;
+		
+		case ATTACHSW:
+		    if (!(attach = *argp++) || *attach == '-')
+			adios (NULL, "missing argument to %s", argp[-2]);
+		    continue;
 	    }
 	} else {
 	    msgs[msgp++] = cp;
@@ -417,7 +443,7 @@ go_to_it:
     closefds (3);
 
     for (msgnum = 0; msgnum < msgp; msgnum++) {
-	switch (sendsbr (vec, vecp, msgs[msgnum], &st, 1)) {
+	switch (sendsbr (vec, vecp, msgs[msgnum], &st, 1, attach)) {
 	    case DONE: 
 		done (++status);
 	    case NOTOK: 
