@@ -2,7 +2,11 @@
 /*
  * show.c -- show/list messages
  *
- * $Id: show.c,v 1.4 1999/09/12 13:50:12 doug Exp $
+ * $Id: show.c,v 1.6 2003/01/02 04:07:49 kimmo Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -470,7 +474,7 @@ invalid:
 				*bp = '\0';
 			} else {
 			    for (bp = dp; *bp; bp++)
-				if (isspace (*bp)) {
+				if (!istoken (*bp)) {
 				    *bp = '\0';
 				    break;
 				}
