@@ -2,7 +2,11 @@
 /*
  * slocal.c -- asynchronously filter and deliver new mail
  *
- * $Id: slocal.c,v 1.9 2000/03/02 07:52:47 danh Exp $
+ * $Id: slocal.c,v 1.19 2005/12/15 00:45:36 pm215 Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 /*
@@ -17,12 +21,17 @@
  *
  */
 
+/* Changed to use getutent() and friends.  Assumes that when getutent() exists,
+ * a number of other things also exist.  Please check.
+ * Ruud de Rooij <ruud@ruud.org>  Sun, 28 May 2000 17:28:55 +0200
+ */
+
 #include <h/mh.h>
 #include <h/dropsbr.h>
 #include <h/rcvmail.h>
 #include <h/signals.h>
-#include <zotnet/tws/tws.h>
-#include <zotnet/mts/mts.h>
+#include <h/tws.h>
+#include <h/mts.h>
 
 #include <pwd.h>
 #include <signal.h>
@@ -43,16 +52,27 @@ extern int  initgroups(char*, int);
 #ifdef HAVE_DB1_NDBM_H
 #include <db1/ndbm.h>
 #else
+#ifdef HAVE_GDBM_NDBM_H
+#include <gdbm/ndbm.h>
+#else
+#if defined(HAVE_DB_H)
+#define DB_DBM_HSEARCH 1
+#include <db.h>
+#else
 #include <ndbm.h>
 #endif
+#endif
+#endif
 
 #include <utmp.h>
 
-#ifndef UTMP_FILE
-# ifdef _PATH_UTMP
-#  define UTMP_FILE _PATH_UTMP
-# else
-#  define UTMP_FILE "/etc/utmp"
+#ifndef HAVE_GETUTENT
+# ifndef UTMP_FILE
+#  ifdef _PATH_UTMP
+#   define UTMP_FILE _PATH_UTMP
+#  else
+#   define UTMP_FILE "/etc/utmp"
+#  endif
 # endif
 #endif
 
@@ -445,7 +465,7 @@ localmail (int fd, char *mdlvr)
 static int
 usr_delivery (int fd, char *delivery, int su)
 {
-    int i, accept, status, won, vecp, next;
+    int i, accept, status=1, won, vecp, next;
     char *field, *pattern, *action, *result, *string;
     char buffer[BUFSIZ], tmpbuf[BUFSIZ];
     char *cp, *vec[NVEC];
@@ -649,6 +669,8 @@ usr_delivery (int fd, char *delivery, int su)
 		break;
 	}
 
+	if (status) next = 0;	/* action failed, mark for 'N' result */
+
 	if (accept && status == 0)
 	    won++;
     }
@@ -931,6 +953,36 @@ lookup (struct pair *pairs, char *key)
  * logged in.
  */
 
+#ifdef HAVE_GETUTENT
+static int
+logged_in (void)
+{
+    struct utmp * utp;
+
+    if (utmped)
+        return utmped;
+
+    setutent();
+
+    while ((utp = getutent()) != NULL) {
+        if (
+#ifdef HAVE_UTMP_UT_TYPE
+		utp->ut_type == USER_PROCESS
+                &&
+#endif
+		utp->ut_name[0] != 0
+                && strncmp (user, utp->ut_name, sizeof(utp->ut_name)) == 0) {
+            if (debug)
+                continue;
+            endutent();
+            return (utmped = DONE);
+        }
+    }
+
+    endutent();
+    return (utmped = NOTOK);
+}
+#else
 static int
 logged_in (void)
 {
@@ -956,7 +1008,7 @@ logged_in (void)
     fclose (uf);
     return (utmped = NOTOK);
 }
-
+#endif
 
 #define	check(t,a,b)		if (t < a || t > b) return -1
 #define	cmpar(h1,m1,h2,m2)	if (h1 < h2 || (h1 == h2 && m1 < m2)) return 0
