@@ -2,7 +2,11 @@
 /*
  * whatnowproc.c -- exec the "whatnowproc"
  *
- * $Id$
+ * $Id: whatnowproc.c,v 1.3 2002/07/02 22:09:15 kenh Exp $
+ *
+ * This code is Copyright (c) 2002, by the authors of nmh.  See the
+ * COPYRIGHT file in the root directory of the nmh distribution for
+ * complete copyright information.
  */
 
 #include <h/mh.h>
@@ -17,11 +21,16 @@
  * it will call this routine directly without exec'ing it.
  */
 
+/* from whatnowsbr.c */
+int WhatNow (int, char **);
+
+
 int
 what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
           struct msgs *mp, char *text, int inplace, char *cwd)
 {
     int found, k, msgnum, vecp;
+    int len, buflen;
     register char *bp;
     char buffer[BUFSIZ], *vec[MAXARGS];
 
@@ -38,7 +47,7 @@ what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
 	if (mp == NULL || *altmsg == '/' || cwd == NULL)
 	    m_putenv ("mhaltmsg", altmsg);
 	else {
-	    sprintf (buffer, "%s/%s", mp->foldpath, altmsg);
+	    snprintf (buffer, sizeof(buffer), "%s/%s", mp->foldpath, altmsg);
 	    m_putenv ("mhaltmsg", buffer);
 	}
     } else {
@@ -46,7 +55,7 @@ what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
     }
     if ((bp = getenv ("mhaltmsg")))/* XXX */
 	m_putenv ("editalt", bp);
-    sprintf (buffer, "%d", dist);
+    snprintf (buffer, sizeof(buffer), "%d", dist);
     m_putenv ("mhdist", buffer);
     if (nedit) {
 	unputenv ("mheditor");
@@ -54,24 +63,30 @@ what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
 	m_putenv ("mheditor", ed ? ed : (ed = context_find ("editor"))
 	    ? ed : defaulteditor);
     }
-    sprintf (buffer, "%d", use);
+    snprintf (buffer, sizeof(buffer), "%d", use);
     m_putenv ("mhuse", buffer);
 
     unputenv ("mhmessages");
     unputenv ("mhannotate");
     unputenv ("mhinplace");
+
     if (text && mp && !is_readonly(mp)) {
 	found = 0;
 	bp = buffer;
+	buflen = sizeof(buffer);
 	for (msgnum = mp->lowmsg; msgnum <= mp->hghmsg; msgnum++) {
 	    if (is_selected(mp, msgnum)) {
-		sprintf (bp, "%s%s", found ? " " : "", m_name (msgnum));
-		bp += strlen (bp);
+		snprintf (bp, buflen, "%s%s", found ? " " : "", m_name (msgnum));
+		len = strlen (bp);
+		bp += len;
+		buflen -= len;
 		for (k = msgnum + 1; k <= mp->hghmsg && is_selected(mp, k); k++)
 		    continue;
 		if (--k > msgnum) {
-		    sprintf (bp, "-%s", m_name (k));
-		    bp += strlen (bp);
+		    snprintf (bp, buflen, "-%s", m_name (k));
+		    len = strlen (bp);
+		    bp += len;
+		    buflen -= len;
 		}
 		msgnum = k + 1;
 		found++;
@@ -80,7 +95,7 @@ what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
 	if (found) {
 	    m_putenv ("mhmessages", buffer);
 	    m_putenv ("mhannotate", text);
-	    sprintf (buffer, "%d", inplace);
+	    snprintf (buffer, sizeof(buffer), "%d", inplace);
 	    m_putenv ("mhinplace", buffer);
 	}
     }
